package tech.mercantec.easyeat.helpers

import android.content.Context
import android.util.Log
import kotlinx.serialization.Serializable
import tech.mercantec.easyeat.models.Ingredient
import tech.mercantec.easyeat.models.Recipe

@Serializable
data class GenerateRecipeRequest(val dish: String, val language: String, val numberOfRecipes: Int, val allergi: Array<String>)

fun generateRecipeWithAI(ctx: Context, title: String, language: String): Recipe {
    return requestJson<GenerateRecipeRequest, Recipe>(ctx, "POST", "/api/Recipe/chatbot", GenerateRecipeRequest(title, language, 1, arrayOf()))
}

fun createRecipe(ctx: Context, recipe: Recipe) {
    requestJson<Recipe, Boolean>(ctx, "POST", "/api/recipe/create", recipe)
}

fun updateRecipe(ctx: Context, id: Int, recipe: Recipe) {
    requestJson<Recipe, Boolean>(ctx, "PUT", "/api/recipe/edit/$id", recipe)
}

@Serializable
data class GetAllRecipesResponse(val id: Int, val name: String, val description: String)

fun getAllRecipes(ctx: Context): List<GetAllRecipesResponse> {
    return requestJson<Unit, List<GetAllRecipesResponse>>(ctx, "GET", "/api/Recipe/getall", null)
}

@Serializable
data class RecipeDetailsResponse(val recipe: Recipe)

fun getRecipeDetails(ctx: Context, id: Int): Recipe {
    return requestJson<Unit, Recipe>(ctx, "GET", "/api/Recipe/get/$id", null)
}

